# Changelog

## 0.1.0-alpha.35 (2025-09-10)

Full Changelog: [v0.1.0-alpha.34...v0.1.0-alpha.35](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.34...v0.1.0-alpha.35)

### Features

* **api:** api update ([14ba96b](https://github.com/babelcloud/gbox-sdk-py/commit/14ba96b4e54b3af3767ea7c3f0899785223a6c33))
* **api:** api update ([fd08fcf](https://github.com/babelcloud/gbox-sdk-py/commit/fd08fcfd26405247d846e65a7204879d432b8caf))
* **media:** add getMedia and getMediaInfo methods for media retrieval ([9987ec8](https://github.com/babelcloud/gbox-sdk-py/commit/9987ec88158ee018f55f204509a22b760976696e))

## 0.1.0-alpha.34 (2025-09-09)

Full Changelog: [v0.1.0-alpha.33...v0.1.0-alpha.34](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.33...v0.1.0-alpha.34)

### Features

* api update ([7887e28](https://github.com/babelcloud/gbox-sdk-py/commit/7887e2831d3f89278c5bf5aefe32146a4fae0727))
* api update ([d384ce5](https://github.com/babelcloud/gbox-sdk-py/commit/d384ce56b44af32340e98d23517c8deae8eadecc))
* **api:** api update ([8739b30](https://github.com/babelcloud/gbox-sdk-py/commit/8739b30d5caff7444086564b804aa00d8ad91094))
* **api:** api update ([1686cd9](https://github.com/babelcloud/gbox-sdk-py/commit/1686cd950446035229318cf2ef808684fec38174))
* **api:** api update ([07d685b](https://github.com/babelcloud/gbox-sdk-py/commit/07d685bcfc41803bcec32bd44c4ef9c43920548e))
* **api:** api update ([72d3d68](https://github.com/babelcloud/gbox-sdk-py/commit/72d3d687dcc0bd4d1544bc9efe748803f4b577e2))
* **api:** api update ([ac56fcc](https://github.com/babelcloud/gbox-sdk-py/commit/ac56fccb5526092c98b930485ec4a6ae98490d07))
* **api:** api update ([2c5f996](https://github.com/babelcloud/gbox-sdk-py/commit/2c5f9964dd41db320dbb7dbc7dad5b318519a71e))
* **api:** api update ([597ff88](https://github.com/babelcloud/gbox-sdk-py/commit/597ff882099cb5f784c2e96b01b69d07734875cf))
* **api:** api update ([8fd05e0](https://github.com/babelcloud/gbox-sdk-py/commit/8fd05e0675ce693233d6fc6f210fefd2a363b7fd))
* **api:** api update ([5b8cc2f](https://github.com/babelcloud/gbox-sdk-py/commit/5b8cc2fc140d2ecb9b047578b00482786745823a))
* **api:** api update ([66d2e3e](https://github.com/babelcloud/gbox-sdk-py/commit/66d2e3ea661c528041ee01ed81e3dcf7fc4bc0f9))
* **api:** api update ([c6e6a20](https://github.com/babelcloud/gbox-sdk-py/commit/c6e6a203825e5c5b418228412118983585c12bf1))
* **api:** api update ([e85718d](https://github.com/babelcloud/gbox-sdk-py/commit/e85718d8d583843a36aaa4d63f4add9dcdafea88))
* **api:** api update ([2d3f0ba](https://github.com/babelcloud/gbox-sdk-py/commit/2d3f0bab05b27736a9aedd6c20b298e877437511))
* **api:** api update ([6fad226](https://github.com/babelcloud/gbox-sdk-py/commit/6fad2260f4faf32db26304e4d970c5328c23b80b))
* **api:** api update ([1d71775](https://github.com/babelcloud/gbox-sdk-py/commit/1d7177509d5f5399b6f38045914f6fa63a4b75b8))
* **api:** api update ([5c26be6](https://github.com/babelcloud/gbox-sdk-py/commit/5c26be66bd16fdc471bc6c1ded0c95bc1844526c))
* **api:** api update ([e1cf29a](https://github.com/babelcloud/gbox-sdk-py/commit/e1cf29a476ab1b09f58018d340b3dcf2729b2386))
* **api:** api update ([8a6a11b](https://github.com/babelcloud/gbox-sdk-py/commit/8a6a11bccb0ade64dd304c0ac642b05b2301a189))
* **api:** api update ([73cff0a](https://github.com/babelcloud/gbox-sdk-py/commit/73cff0ae362ebf8f0440014870f15f1e86606e2d))
* **api:** api update ([4acaf69](https://github.com/babelcloud/gbox-sdk-py/commit/4acaf69ed661388dd1d62838ffe57ff03a6c6100))
* **api:** api update ([152897f](https://github.com/babelcloud/gbox-sdk-py/commit/152897f18839c2c74716ffa16970f32757b3406d))
* **api:** api update ([12bc484](https://github.com/babelcloud/gbox-sdk-py/commit/12bc4845e3afcd18c80eb343454a77bf6921b1b3))
* **api:** api update ([d619ae7](https://github.com/babelcloud/gbox-sdk-py/commit/d619ae7941657a1d99175d52390ed088b0648ef8))
* **api:** api update ([11190c9](https://github.com/babelcloud/gbox-sdk-py/commit/11190c927f9eb6936700202267324002730fea4e))
* **api:** api update ([15f75f4](https://github.com/babelcloud/gbox-sdk-py/commit/15f75f4bc0e4d508662ebfd984431761feed19c9))
* **api:** api update ([4183fe9](https://github.com/babelcloud/gbox-sdk-py/commit/4183fe9bb361afae41e986d4d872ca1ced818ff5))
* **api:** api update ([6def2c4](https://github.com/babelcloud/gbox-sdk-py/commit/6def2c43752f24cf9d914789856fc3e20b6b3c28))
* **api:** api update ([69a5f8d](https://github.com/babelcloud/gbox-sdk-py/commit/69a5f8db44846556b8c9fbae45c2f20f9d48ae1f))
* **box:** update command method to accept single command string and add getConnectAddress method in AndroidBoxOperator ([0e7dfaa](https://github.com/babelcloud/gbox-sdk-py/commit/0e7dfaa9de1730a1da3bb91870c4420637597d0c))
* improve future compat with pydantic v3 ([cd94645](https://github.com/babelcloud/gbox-sdk-py/commit/cd94645a1a9d8e893a4ae49cef6e51d0fee4fa4e))
* **types:** replace List[str] with SequenceNotStr in params ([8b86098](https://github.com/babelcloud/gbox-sdk-py/commit/8b86098561019a0cac8dd9a54a5ca3f3f234cff6))


### Bug Fixes

* avoid newer type syntax ([5ae3fcc](https://github.com/babelcloud/gbox-sdk-py/commit/5ae3fcc51edbef75f443f8253fe91cb6e015fd9a))
* lint ([51e267c](https://github.com/babelcloud/gbox-sdk-py/commit/51e267cabf54c85182bfbb9c14b7313038889b0b))
* lint changes ([edd975d](https://github.com/babelcloud/gbox-sdk-py/commit/edd975dbc3570163342b480b692d311b33e374ee))


### Chores

* **internal:** add Sequence related utils ([bd145b5](https://github.com/babelcloud/gbox-sdk-py/commit/bd145b5cbfe47c738dd0bbd7695aa4fd1dab2a22))
* **internal:** change ci workflow machines ([d54ec35](https://github.com/babelcloud/gbox-sdk-py/commit/d54ec355ed0f93a7a3ebda37a558281f8ade185a))
* **internal:** codegen related update ([96e3e8b](https://github.com/babelcloud/gbox-sdk-py/commit/96e3e8b54931faf5c86f9bdb033995ac3cc5acd4))
* **internal:** move mypy configurations to `pyproject.toml` file ([f9fa525](https://github.com/babelcloud/gbox-sdk-py/commit/f9fa52593f31ab959e36fbd34b8e178ff49a298e))
* **internal:** update pyright exclude list ([b9be869](https://github.com/babelcloud/gbox-sdk-py/commit/b9be869c19d019b5890c2280706ad284ccb118d1))
* update github action ([88c9d20](https://github.com/babelcloud/gbox-sdk-py/commit/88c9d204e3583ba73ea4de7b6b409c3ada39ed69))

## 0.1.0-alpha.33 (2025-08-18)

Full Changelog: [v0.1.0-alpha.32...v0.1.0-alpha.33](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.32...v0.1.0-alpha.33)

### Features

* api update ([dc5609b](https://github.com/babelcloud/gbox-sdk-py/commit/dc5609b054ee8fd7510d42009953ce8b93e43d2a))
* **api:** api update ([6f4a623](https://github.com/babelcloud/gbox-sdk-py/commit/6f4a6236c0d9f5339ae8809a959c50eb2c28cf83))
* **api:** api update ([5c2c0ac](https://github.com/babelcloud/gbox-sdk-py/commit/5c2c0ac0f517a575fd7f31b9859c07a83c512744))
* **api:** api update ([f0d6a96](https://github.com/babelcloud/gbox-sdk-py/commit/f0d6a96f4592769f15c5a9c19461899d46a994af))

## 0.1.0-alpha.32 (2025-08-15)

Full Changelog: [v0.1.0-alpha.31...v0.1.0-alpha.32](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.31...v0.1.0-alpha.32)

### Features

* api update ([58aa53f](https://github.com/babelcloud/gbox-sdk-py/commit/58aa53fd9346ef69c47fa8244fc6afb3a9266b9c))

## 0.1.0-alpha.31 (2025-08-15)

Full Changelog: [v0.1.0-alpha.30...v0.1.0-alpha.31](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.30...v0.1.0-alpha.31)

### Features

* api update ([6135aeb](https://github.com/babelcloud/gbox-sdk-py/commit/6135aeb42fffe11b586e91e76c2ae9fd9f1d8021))
* **api:** api update ([21c2c8d](https://github.com/babelcloud/gbox-sdk-py/commit/21c2c8dd5d75a6d9cd87b56dd0330e8ffd619733))
* **api:** api update ([e18e36d](https://github.com/babelcloud/gbox-sdk-py/commit/e18e36d1b9045f353945210c85db457dd5af8362))

## 0.1.0-alpha.30 (2025-08-13)

Full Changelog: [v0.1.0-alpha.29...v0.1.0-alpha.30](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.29...v0.1.0-alpha.30)

### Features

* api update ([eb766c2](https://github.com/babelcloud/gbox-sdk-py/commit/eb766c2da8352939360c6517d0a77e4b5f73ea4f))
* **api:** api update ([5e0f5c9](https://github.com/babelcloud/gbox-sdk-py/commit/5e0f5c955fb3d382c43b584b46042d75b7bcf8fa))
* **api:** api update ([98a8027](https://github.com/babelcloud/gbox-sdk-py/commit/98a8027c351127f13373340303931a8134087de7))
* **api:** api update ([7723824](https://github.com/babelcloud/gbox-sdk-py/commit/772382463edf274e7f5179869e450711d4e6c6c2))
* **api:** api update ([71f87a2](https://github.com/babelcloud/gbox-sdk-py/commit/71f87a26764264ac1de6d852785ca7a86b2cb562))
* **api:** api update ([1b54801](https://github.com/babelcloud/gbox-sdk-py/commit/1b548014584df164ac8b615c204faf355b3e32dc))
* **api:** api update ([afb1c49](https://github.com/babelcloud/gbox-sdk-py/commit/afb1c4941fc4c4c1170e34ab1edf3326b9381118))
* **api:** api update ([54b0703](https://github.com/babelcloud/gbox-sdk-py/commit/54b0703c780c018cab139cd59d6a82aa84723de0))
* **api:** api update ([5f88b45](https://github.com/babelcloud/gbox-sdk-py/commit/5f88b45bc27e75909008e9cabf5d0aee23255b36))
* **api:** api update ([da96920](https://github.com/babelcloud/gbox-sdk-py/commit/da96920d78f21908e8709ed7d78abd5fa5d72ad1))
* **api:** api update ([22c5ee9](https://github.com/babelcloud/gbox-sdk-py/commit/22c5ee9f90f40b4b208d01fb0efcf2e18350cceb))
* **api:** api update ([b61220b](https://github.com/babelcloud/gbox-sdk-py/commit/b61220ba9cb0eca256daf12202dcbd372cfea285))
* **api:** api update ([ff82b46](https://github.com/babelcloud/gbox-sdk-py/commit/ff82b462f6f4408355249d53307a1d4f6d765068))
* **api:** api update ([f1fd2e1](https://github.com/babelcloud/gbox-sdk-py/commit/f1fd2e1b5b98d4f7501c13bc6591d1057d55e11a))
* **api:** api update ([1c1dc28](https://github.com/babelcloud/gbox-sdk-py/commit/1c1dc284b7ee2251afa44a19d085c8a2016dc764))
* **api:** api update ([1753a4e](https://github.com/babelcloud/gbox-sdk-py/commit/1753a4e30597f570c585b15ef9e898655039cb2e))
* **api:** api update ([ecae143](https://github.com/babelcloud/gbox-sdk-py/commit/ecae14384a5a4837fda4eff10836a7cd3a7721b3))


### Bug Fixes

* lint ([b739698](https://github.com/babelcloud/gbox-sdk-py/commit/b7396981acd8d3b74ee8809b09ec1ef512c59c79))


### Chores

* **internal:** codegen related update ([302b7ab](https://github.com/babelcloud/gbox-sdk-py/commit/302b7ab125506f4583c9e64ce5b0926a44b60863))
* **internal:** fix ruff target version ([318195e](https://github.com/babelcloud/gbox-sdk-py/commit/318195e0b4d50a843d7c333ab1734ee3324afdbc))
* **internal:** update comment in script ([540a35d](https://github.com/babelcloud/gbox-sdk-py/commit/540a35d14be28be19ca9e9e35e54d50bb36b1428))
* update @stainless-api/prism-cli to v5.15.0 ([68c4951](https://github.com/babelcloud/gbox-sdk-py/commit/68c49512d4981f3ba9a103cb4d40e426c04f5355))

## 0.1.0-alpha.29 (2025-08-04)

Full Changelog: [v0.1.0-alpha.28...v0.1.0-alpha.29](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.28...v0.1.0-alpha.29)

### Features

* add switch tab method to BrowserOperator class ([05554d2](https://github.com/babelcloud/gbox-sdk-py/commit/05554d266a077969fcfca1d8db618cd33a6bbf8a))
* **api:** api update ([8972c42](https://github.com/babelcloud/gbox-sdk-py/commit/8972c42a3bd729ea87874d808fe7f0aee1dd8e20))
* **api:** api update ([0bd65ca](https://github.com/babelcloud/gbox-sdk-py/commit/0bd65ca87eaf2e3afab9b85efde747e08c10b91d))
* **api:** api update ([8ab961a](https://github.com/babelcloud/gbox-sdk-py/commit/8ab961a2a3625d5116ec8f7fda071f291fe9b387))
* **api:** api update ([1e18a83](https://github.com/babelcloud/gbox-sdk-py/commit/1e18a835ed793e5c5c06bf1f8f262b7e35f6b210))
* **api:** api update ([f8f4c69](https://github.com/babelcloud/gbox-sdk-py/commit/f8f4c69937720a15af620f10fda2320a6527723c))
* **api:** api update ([0e25380](https://github.com/babelcloud/gbox-sdk-py/commit/0e2538084c1bfc08ea7989acc200df39dae97df4))
* **api:** api update ([fb78fcf](https://github.com/babelcloud/gbox-sdk-py/commit/fb78fcfc55ed7d1c30de72bf946d6591b814b7ad))
* **client:** support file upload requests ([0593ba6](https://github.com/babelcloud/gbox-sdk-py/commit/0593ba6b2dc353e5548e6a6bb4f5418e420fd686))


### Bug Fixes

* lint ([ad692d6](https://github.com/babelcloud/gbox-sdk-py/commit/ad692d63e828a858e6fdbd34c31128bf32c2e7d9))


### Chores

* **project:** add settings file for vscode ([786613e](https://github.com/babelcloud/gbox-sdk-py/commit/786613e3756536f52ad4750cf7ab92db4670af0b))

## 0.1.0-alpha.28 (2025-07-25)

Full Changelog: [v0.1.0-alpha.27...v0.1.0-alpha.28](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.27...v0.1.0-alpha.28)

### Features

* add browser tab methods ([31a8a81](https://github.com/babelcloud/gbox-sdk-py/commit/31a8a813091bb2f3fa40a2855c4642a180ee2899))
* **api:** api update ([ac9ed57](https://github.com/babelcloud/gbox-sdk-py/commit/ac9ed57207dd9a86c1c1c46ad064b1b9c01ed41b))
* **api:** api update ([954e23b](https://github.com/babelcloud/gbox-sdk-py/commit/954e23bbc3f1025ae2fb86648e05526ffa281705))

## 0.1.0-alpha.27 (2025-07-23)

Full Changelog: [v0.1.0-alpha.26...v0.1.0-alpha.27](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.26...v0.1.0-alpha.27)

## 0.1.0-alpha.26 (2025-07-23)

Full Changelog: [v0.1.0-alpha.25...v0.1.0-alpha.26](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.25...v0.1.0-alpha.26)

### Features

* **api:** api update ([ebed5cb](https://github.com/babelcloud/gbox-sdk-py/commit/ebed5cbb9ce812b8b0962cc191ef7378d816b6b1))
* **api:** api update ([6a2f7f7](https://github.com/babelcloud/gbox-sdk-py/commit/6a2f7f78c33124bf159e964565d8edf6e29fa28a))
* **api:** api update ([46430f5](https://github.com/babelcloud/gbox-sdk-py/commit/46430f5ae0f3c875229aabcfa86800d613950b34))
* **api:** api update ([c5233d6](https://github.com/babelcloud/gbox-sdk-py/commit/c5233d6e518ddaf53d3fba5fe38d0fd8da31adac))
* **api:** api update ([4345abf](https://github.com/babelcloud/gbox-sdk-py/commit/4345abff14aacacc38378ebd73228aa4e4796970))
* **api:** api update ([a807c16](https://github.com/babelcloud/gbox-sdk-py/commit/a807c16b49eefbfffae5a87cdb8c99edc1b4aafb))
* **api:** api update ([69191d1](https://github.com/babelcloud/gbox-sdk-py/commit/69191d151b664997e8127535dae5cb830d2afbf5))
* **api:** api update ([2bd8500](https://github.com/babelcloud/gbox-sdk-py/commit/2bd85009b580b72e77b6ae2c4414a98b5622e8a3))
* **api:** api update ([ec90c7f](https://github.com/babelcloud/gbox-sdk-py/commit/ec90c7f8b17889354bf15b17226056a98a529c86))
* **api:** api update ([66a984a](https://github.com/babelcloud/gbox-sdk-py/commit/66a984acffe850119f4ac3c96ff85453499debf2))
* **api:** api update ([07af56a](https://github.com/babelcloud/gbox-sdk-py/commit/07af56aec489067c8541f6d5a60894a17abb7d77))
* **api:** api update ([eda3b98](https://github.com/babelcloud/gbox-sdk-py/commit/eda3b9841969a246268f200acb75cdebaf44497c))
* **api:** api update ([f1ee014](https://github.com/babelcloud/gbox-sdk-py/commit/f1ee01412154a6d431eace480f63062ca40c173d))
* **api:** api update ([5233d66](https://github.com/babelcloud/gbox-sdk-py/commit/5233d6665a06fd60afb86f195180fe19e077e33f))
* **api:** api update ([1afac7b](https://github.com/babelcloud/gbox-sdk-py/commit/1afac7bafd20b6c522d5270c8d932ce036ae23ec))
* **api:** api update ([916adf3](https://github.com/babelcloud/gbox-sdk-py/commit/916adf312dc1f75b102e732342e5875c5102099c))
* **api:** extend action classes to include screenshot delay and add extract and screen layout methods ([7ae0806](https://github.com/babelcloud/gbox-sdk-py/commit/7ae080646445a61cbc219ed801c8c74f6b2b2c14))
* clean up environment call outs ([0111f73](https://github.com/babelcloud/gbox-sdk-py/commit/0111f738a21bad17d5fc6ea98757e4f07213e24a))
* command and run code support streaming output ([e9e7bbd](https://github.com/babelcloud/gbox-sdk-py/commit/e9e7bbd85f0bb7d2553b0d8e721049341c1900ef))
* sync data after android pkg open, close or restart ([3780890](https://github.com/babelcloud/gbox-sdk-py/commit/37808902f5aa33707666605fe8c6e76d2bf79b7e))


### Bug Fixes

* **client:** don't send Content-Type header on GET requests ([e697be7](https://github.com/babelcloud/gbox-sdk-py/commit/e697be739e861dad822411b2370f0dcd773308dd))
* **parsing:** ignore empty metadata ([90e7621](https://github.com/babelcloud/gbox-sdk-py/commit/90e76216b7c30296fed4541c068680098bebd0ec))
* **parsing:** parse extra field types ([daef950](https://github.com/babelcloud/gbox-sdk-py/commit/daef9503102a8a1a3773c53b12004f68274c91f6))


### Chores

* **internal:** codegen related update ([69963ef](https://github.com/babelcloud/gbox-sdk-py/commit/69963efa0c5d80238a12bbcf697bb61ef54a8ee2))
* **readme:** fix version rendering on pypi ([69ee15a](https://github.com/babelcloud/gbox-sdk-py/commit/69ee15a83ac7638d7d5004ea6fe2d2273aba60af))

## 0.1.0-alpha.25 (2025-07-10)

Full Changelog: [v0.1.0-alpha.24...v0.1.0-alpha.25](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.24...v0.1.0-alpha.25)

### Features

* **api:** api update ([e4c5c37](https://github.com/babelcloud/gbox-sdk-py/commit/e4c5c37aa9f00594d5477ace37064678aab65efa))


### Bug Fixes

* list box params ([3bab4cb](https://github.com/babelcloud/gbox-sdk-py/commit/3bab4cb5c8ef5b934a61b84adfbd1c26280c96fe))

## 0.1.0-alpha.24 (2025-07-10)

Full Changelog: [v0.1.0-alpha.23...v0.1.0-alpha.24](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.23...v0.1.0-alpha.24)

### Features

* **api:** api update ([4943893](https://github.com/babelcloud/gbox-sdk-py/commit/4943893b2a4757156b2d1f73b967ab6523f3a3a8))
* **api:** api update ([f2e7d4b](https://github.com/babelcloud/gbox-sdk-py/commit/f2e7d4b019e99ede81d0b5540091900e5a47754d))


### Bug Fixes

* android methods ([98e7c66](https://github.com/babelcloud/gbox-sdk-py/commit/98e7c667eff50d8ddd25ceef0dbbf435293f7e02))
* **parsing:** correctly handle nested discriminated unions ([dee95fa](https://github.com/babelcloud/gbox-sdk-py/commit/dee95fa0b2a713d094ed01890c769c84d76dfbfa))

## 0.1.0-alpha.23 (2025-07-09)

Full Changelog: [v0.1.0-alpha.22...v0.1.0-alpha.23](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.22...v0.1.0-alpha.23)

### Features

* **action:** add AI action support and extend ActionAIParams ([c58eb20](https://github.com/babelcloud/gbox-sdk-py/commit/c58eb20c4ef2c1248a30cde0983426faffccf7f6))
* **action:** enhance screenshot method to support optional parameters and file saving ([24b5108](https://github.com/babelcloud/gbox-sdk-py/commit/24b51082f8c77035a26f532c7b60917aeac173f9))
* **android, fs:** enhance APK installation handling to support multiple input formats including local paths, file URLs, and HTTP URLs ([cc0637b](https://github.com/babelcloud/gbox-sdk-py/commit/cc0637becea76d6772b8b9bb98d09881aba35b8e))
* **api:** api update ([68a9fed](https://github.com/babelcloud/gbox-sdk-py/commit/68a9fede6b7d427cc5276df731c1aa67896d55d6))
* **api:** api update ([b0ca803](https://github.com/babelcloud/gbox-sdk-py/commit/b0ca803ba3503f821847ac62e46b51d7a970fb37))
* **api:** api update ([9b2b3dd](https://github.com/babelcloud/gbox-sdk-py/commit/9b2b3dd3e05f8df314126b06e32cd1db4a562f0e))
* **api:** api update ([0c746f8](https://github.com/babelcloud/gbox-sdk-py/commit/0c746f837658b0250cccb92e9296bb09b3f2c0ed))
* **api:** api update ([2a7a023](https://github.com/babelcloud/gbox-sdk-py/commit/2a7a023a2569903a1510ca80da4da281f46f6c5a))
* **api:** api update ([62c5826](https://github.com/babelcloud/gbox-sdk-py/commit/62c5826c5521d045211924e405042588f1876823))
* **api:** api update ([9d8a593](https://github.com/babelcloud/gbox-sdk-py/commit/9d8a5937b9013cceb8cd2daa30f411f6ad20d034))
* **api:** api update ([06cac89](https://github.com/babelcloud/gbox-sdk-py/commit/06cac894f3ffdb9188722aa3ef581992791cf3bc))
* **api:** api update ([21af4de](https://github.com/babelcloud/gbox-sdk-py/commit/21af4de46f968b56449534641ca3316a7439ca0f))
* **api:** api update ([6752ddd](https://github.com/babelcloud/gbox-sdk-py/commit/6752ddd330385562c5d1ed55298f65366aa79ea6))
* **api:** api update ([71f3cf6](https://github.com/babelcloud/gbox-sdk-py/commit/71f3cf6138c16fbf099acbc0a152523297c67f9a))
* **api:** api update ([a1c2ae6](https://github.com/babelcloud/gbox-sdk-py/commit/a1c2ae6faa6839414c7dcac8089c9aca40312fd5))
* **api:** api update ([89d5f2d](https://github.com/babelcloud/gbox-sdk-py/commit/89d5f2d2482d987f00b8938f3d6ce7e3da433a42))
* **api:** api update ([bf1941e](https://github.com/babelcloud/gbox-sdk-py/commit/bf1941e1b536b3238b140bea1d2b27526a61980d))
* **api:** api update ([385e786](https://github.com/babelcloud/gbox-sdk-py/commit/385e7860f40a3c8ac69dd8ababd0081fcaeffd67))
* **api:** api update ([1ce1459](https://github.com/babelcloud/gbox-sdk-py/commit/1ce1459fdb30f062267b3cd03798f1aa53d4c8d1))
* **api:** api update ([8ef3437](https://github.com/babelcloud/gbox-sdk-py/commit/8ef34373e38cbbf32ad6d00a8af6ed61dc7747d1))
* **api:** api update ([1a97852](https://github.com/babelcloud/gbox-sdk-py/commit/1a9785208550d2233505c115ba245a972762e9c1))
* **api:** api update ([df5dfee](https://github.com/babelcloud/gbox-sdk-py/commit/df5dfee51f249af27ea1f2cc9a0b02a80ba2c199))
* **api:** api update ([3da7479](https://github.com/babelcloud/gbox-sdk-py/commit/3da7479394855329abb7c747f378ed0347bdb291))
* **api:** api update ([784ca67](https://github.com/babelcloud/gbox-sdk-py/commit/784ca673d73d1e651a021787b4f5e0f6eb0da939))
* **api:** api update ([f371a5d](https://github.com/babelcloud/gbox-sdk-py/commit/f371a5d0fe10450dc19c5fd59d34ca7ecf6e6311))
* **api:** api update ([9105104](https://github.com/babelcloud/gbox-sdk-py/commit/9105104f2b5d1436b669702c9bb219d9a906c996))
* **api:** api update ([8133a2e](https://github.com/babelcloud/gbox-sdk-py/commit/8133a2eb0e80f03d24a5f8c473dac44cde0b952e))
* **api:** api update ([a3ee1c8](https://github.com/babelcloud/gbox-sdk-py/commit/a3ee1c81a53defc05d10c805333158076e1dee9e))
* **api:** api update ([90f9822](https://github.com/babelcloud/gbox-sdk-py/commit/90f9822d821b244786cd6ce0a2f3a0829b61e9e9))
* **api:** api update ([002833a](https://github.com/babelcloud/gbox-sdk-py/commit/002833ad9c955c670cfc1d3ec3164f8cf15a7625))
* **api:** api update ([bbe9346](https://github.com/babelcloud/gbox-sdk-py/commit/bbe9346f8f29518230ee5e68d6c1d9ac1280000a))
* **api:** api update ([62a2c4b](https://github.com/babelcloud/gbox-sdk-py/commit/62a2c4b1ab5a2990a0982620e53c27967a8a0bbf))
* **api:** api update ([5755604](https://github.com/babelcloud/gbox-sdk-py/commit/575560487caff6e1c0b323f71b1aa4d9decf2ca8))
* **api:** api update ([e151cf3](https://github.com/babelcloud/gbox-sdk-py/commit/e151cf3085785bfb9adde4f1717658d2ab9df725))
* **api:** api update ([12d4278](https://github.com/babelcloud/gbox-sdk-py/commit/12d4278f0fe3a7c669443e74a5e6c1462355db8a))
* **api:** api update ([9ad1d28](https://github.com/babelcloud/gbox-sdk-py/commit/9ad1d283116f9d15d32a0567b499380a1d49a432))
* **api:** api update ([1829e97](https://github.com/babelcloud/gbox-sdk-py/commit/1829e97c1644c31b3a1b658b67a9b7a556141253))
* **api:** api update ([af01124](https://github.com/babelcloud/gbox-sdk-py/commit/af01124f751920d072c485ba87bbb4234fd5203f))
* **api:** api update ([1e313ed](https://github.com/babelcloud/gbox-sdk-py/commit/1e313ed95b981c6751066167c5283780058fbb42))
* **api:** api update ([0361074](https://github.com/babelcloud/gbox-sdk-py/commit/0361074903fab99a6f3d2eb129d0b7a193d2cfbd))
* **api:** api update ([89eb38e](https://github.com/babelcloud/gbox-sdk-py/commit/89eb38e1de1df468c281efe0b8ed0c207587cc8a))
* **api:** api update ([3a428f4](https://github.com/babelcloud/gbox-sdk-py/commit/3a428f43b0af327d78160c20a67f4e6f6fe63608))
* **api:** api update ([55ac95e](https://github.com/babelcloud/gbox-sdk-py/commit/55ac95ee15183da8f6550998ab71e45decc8bb74))
* **api:** api update ([bab02cb](https://github.com/babelcloud/gbox-sdk-py/commit/bab02cba5c4bc934278b8103e9629bda225c409f))
* **api:** api update ([bae1c5c](https://github.com/babelcloud/gbox-sdk-py/commit/bae1c5c5338e272ac51728ae0d2eb82f668f273f))
* **api:** api update ([32245ed](https://github.com/babelcloud/gbox-sdk-py/commit/32245edcc14eb4e4552942b9e4781833610a54a6))
* **api:** api update ([0cee4a7](https://github.com/babelcloud/gbox-sdk-py/commit/0cee4a7bf0b4801e99792375e9075fbb61755825))
* **api:** api update ([39ab273](https://github.com/babelcloud/gbox-sdk-py/commit/39ab2736256da51ceef7fd72bf87736ebcd856e1))
* **api:** api update ([9b8d6f8](https://github.com/babelcloud/gbox-sdk-py/commit/9b8d6f8958e7f9e3122996298496c947250f3e9e))
* **api:** api update ([462b313](https://github.com/babelcloud/gbox-sdk-py/commit/462b3138f408b784c3ea1fe931db8ed2ef123a9a))
* **api:** api update ([874fb44](https://github.com/babelcloud/gbox-sdk-py/commit/874fb446e1c59d6b17a4c49961c9435a933e61b6))
* **api:** api update ([1ce6554](https://github.com/babelcloud/gbox-sdk-py/commit/1ce6554bba010bc002b490f8baa485b7641b69e5))
* **api:** api update ([55a6d7d](https://github.com/babelcloud/gbox-sdk-py/commit/55a6d7d0e9a46ff993f4f5732be41280656000aa))
* **api:** api update ([75bfcde](https://github.com/babelcloud/gbox-sdk-py/commit/75bfcde9fea96fa035f47367054946a68ea48d34))
* **api:** api update ([1c41908](https://github.com/babelcloud/gbox-sdk-py/commit/1c419083685302a991156bc50148862299383ce0))
* **api:** api update ([33d8679](https://github.com/babelcloud/gbox-sdk-py/commit/33d86797f41da3fc8dd5e255697bd3545cafcad5))
* **api:** api update ([f568c85](https://github.com/babelcloud/gbox-sdk-py/commit/f568c857299cb093c000c2a862192d960ebc1bbd))
* **api:** api update ([9b6f9de](https://github.com/babelcloud/gbox-sdk-py/commit/9b6f9de4aec8c06f7656e56f680079e5959e40f8))
* **api:** api update ([f6fb04b](https://github.com/babelcloud/gbox-sdk-py/commit/f6fb04b5e56de779bb2cc829bbf56966b8b1749b))
* **api:** api update ([975884c](https://github.com/babelcloud/gbox-sdk-py/commit/975884ce6f565dbcd1829028ae7ad5d20dc5bcec))
* **api:** api update ([e3badb0](https://github.com/babelcloud/gbox-sdk-py/commit/e3badb0a6e72f48f3b75897db9bd24f453fcb1bd))
* **api:** api update ([568484b](https://github.com/babelcloud/gbox-sdk-py/commit/568484b9961d267466c382ec36c30b9fac558425))
* **api:** api update ([3277243](https://github.com/babelcloud/gbox-sdk-py/commit/32772434884f859363eee941fbf6d8238cbfb36d))
* **api:** api update ([8cc0a38](https://github.com/babelcloud/gbox-sdk-py/commit/8cc0a38268abaa14acf21d00f9681e35e7869a27))
* **api:** api update ([9029aab](https://github.com/babelcloud/gbox-sdk-py/commit/9029aabb651500a65bbd81d9dc6726627b859180))
* **api:** api update ([8c641f4](https://github.com/babelcloud/gbox-sdk-py/commit/8c641f470a37badd59a53778cb328a440fad50bc))
* **api:** api update ([a820b3f](https://github.com/babelcloud/gbox-sdk-py/commit/a820b3fa2609846515b43a2e6875405a784e2ed2))
* **api:** api update ([4280a67](https://github.com/babelcloud/gbox-sdk-py/commit/4280a67ad066fa691fdf06689adc42cf818e588d))
* **api:** api update ([5a3e3ce](https://github.com/babelcloud/gbox-sdk-py/commit/5a3e3ce9d0f8e058bf168e36a35e673c7fbcc2b3))
* **api:** api update ([f91642f](https://github.com/babelcloud/gbox-sdk-py/commit/f91642f964a2e51647cb054977bedc665d6923e9))
* **api:** api update ([f4efa25](https://github.com/babelcloud/gbox-sdk-py/commit/f4efa25622088a1cfe2fa2187c1d8090368fc3e7))
* **api:** api update ([481f354](https://github.com/babelcloud/gbox-sdk-py/commit/481f35440439916da2836659fdf125086ce12a20))
* **api:** api update ([81beaf6](https://github.com/babelcloud/gbox-sdk-py/commit/81beaf6636b3c250255de43068835ca1a7b7dd95))
* **api:** api update ([4eba864](https://github.com/babelcloud/gbox-sdk-py/commit/4eba8647159e65cd74dfb385f2d958182331eb4a))
* **api:** api update ([cdb0e97](https://github.com/babelcloud/gbox-sdk-py/commit/cdb0e97c8cf191b36a9bf76724db4be676832e64))
* **api:** api update ([7c07d26](https://github.com/babelcloud/gbox-sdk-py/commit/7c07d269a33cb90759d90344e46490408dd822d3))
* **api:** api update ([5cf58a9](https://github.com/babelcloud/gbox-sdk-py/commit/5cf58a901471fce9dca71356b6e23aac91c02bdd))
* **api:** api update ([abe1ca5](https://github.com/babelcloud/gbox-sdk-py/commit/abe1ca5e7e29ba9cb802c52ddf961a71779216fd))
* **api:** api update ([5cce3d5](https://github.com/babelcloud/gbox-sdk-py/commit/5cce3d5b4f7bac209a59c466f196ab46424ed77b))
* **api:** api update ([1dbccff](https://github.com/babelcloud/gbox-sdk-py/commit/1dbccff9140302900f1de07e168421b889b4ed1f))
* **api:** api update ([78e2d17](https://github.com/babelcloud/gbox-sdk-py/commit/78e2d17e5d1620c6542bf934dcfd8305bc8456eb))
* **api:** api update ([7b3e36f](https://github.com/babelcloud/gbox-sdk-py/commit/7b3e36f84004f5a7ea7513dec28730cef8f9728e))
* **api:** api update ([17dbf3a](https://github.com/babelcloud/gbox-sdk-py/commit/17dbf3aa1d6aed4cc9b8ca574ec4f9018b96648e))
* **api:** api update ([56c90f3](https://github.com/babelcloud/gbox-sdk-py/commit/56c90f37772161878298a96e57163afd5f7165a7))
* **api:** api update ([26b0d82](https://github.com/babelcloud/gbox-sdk-py/commit/26b0d8254192669ff10804e51b9935c5af8ddf9f))
* **api:** api update ([f149278](https://github.com/babelcloud/gbox-sdk-py/commit/f1492784c839c750788bdda7a8225bb7f9c72641))
* **api:** api update ([a919aaf](https://github.com/babelcloud/gbox-sdk-py/commit/a919aaf379961c1b7bf3a9d4b16ea716b4857d36))
* **api:** api update ([33de52f](https://github.com/babelcloud/gbox-sdk-py/commit/33de52f43e0f71747ecea3171e8445127904c5a6))
* **api:** api update ([5fe515c](https://github.com/babelcloud/gbox-sdk-py/commit/5fe515c987e40ba6eeada913a9cecff5159cfb33))
* **api:** api update ([0991e0e](https://github.com/babelcloud/gbox-sdk-py/commit/0991e0e88081a6fcbb4cec70a6d92b481f5f9019))
* **api:** api update ([5c1b649](https://github.com/babelcloud/gbox-sdk-py/commit/5c1b649de6650f639dc6723985c293474f477871))
* **api:** api update ([bf932a1](https://github.com/babelcloud/gbox-sdk-py/commit/bf932a145e86dd9d650ca8b221783b97779eeb16))
* **api:** api update ([21423ce](https://github.com/babelcloud/gbox-sdk-py/commit/21423ce58b68b4132947c561f0b6a72facbb1e4f))
* **api:** api update ([516f187](https://github.com/babelcloud/gbox-sdk-py/commit/516f18737316cde5715adac83bebc2c136116f14))
* **api:** api update ([e634222](https://github.com/babelcloud/gbox-sdk-py/commit/e63422205b3a2b7d53c73775b60a8784a33fdb3d))
* **api:** api update ([8b53b53](https://github.com/babelcloud/gbox-sdk-py/commit/8b53b53cf89837d0b49761d09b84fd41dcb7f028))
* **api:** api update ([623b01c](https://github.com/babelcloud/gbox-sdk-py/commit/623b01c6fb6396ec952d7271b2039ec592b62631))
* **api:** api update ([b866218](https://github.com/babelcloud/gbox-sdk-py/commit/b8662185a6544fa80b57496a8a38540ca178960e))
* **api:** api update ([e9775fd](https://github.com/babelcloud/gbox-sdk-py/commit/e9775fd99203595149e9621d44a76e49ff4a2f7e))
* **api:** api update ([3df4a6f](https://github.com/babelcloud/gbox-sdk-py/commit/3df4a6f58c2908e0204835bc13ef48cb31312091))
* **api:** api update ([03ecf6c](https://github.com/babelcloud/gbox-sdk-py/commit/03ecf6c7204bab91c7994d613584206960eaf552))
* **api:** api update ([288ce1b](https://github.com/babelcloud/gbox-sdk-py/commit/288ce1be34525d6be88e5dd0367e21c1f8b2a84b))
* **api:** api update ([245aad5](https://github.com/babelcloud/gbox-sdk-py/commit/245aad5e47e70291c2060e5b7fff6f1ce211ce53))
* **api:** api update ([550cdde](https://github.com/babelcloud/gbox-sdk-py/commit/550cdde72c20c3768ea333b4e4aef27dd9532ec4))
* **api:** api update ([a88dcb9](https://github.com/babelcloud/gbox-sdk-py/commit/a88dcb9bddd7466f1fd45f689203bc6446982fed))
* **api:** api update ([f340cc8](https://github.com/babelcloud/gbox-sdk-py/commit/f340cc8733d2869d760a391ceb3dc6b317ab799a))
* **api:** api update ([5932ca9](https://github.com/babelcloud/gbox-sdk-py/commit/5932ca92ebe8c102d5ef8a9d45be23349a8791b7))
* **api:** api update ([e93c534](https://github.com/babelcloud/gbox-sdk-py/commit/e93c5348a8e18064930110966fc681bdeca93d1b))
* **api:** api update ([43c9c12](https://github.com/babelcloud/gbox-sdk-py/commit/43c9c12e909789d5c31787e32a657e23394a5f3f))
* **api:** api update ([4807b0d](https://github.com/babelcloud/gbox-sdk-py/commit/4807b0d37174f825fb8a6c16ceaa2ead04d7edf8))
* **api:** api update ([10fa17e](https://github.com/babelcloud/gbox-sdk-py/commit/10fa17e08321177a097e5d100eb3903719b7f891))
* **api:** api update ([f59aa66](https://github.com/babelcloud/gbox-sdk-py/commit/f59aa667afa8417a3991d0d9fcc165243481d994))
* **api:** enhance box creation and management with unified parameters for Android and Linux boxes ([12227dc](https://github.com/babelcloud/gbox-sdk-py/commit/12227dcce5a9339e8ff69b61ea6748c73f5f1ff8))
* **box:** allow optional parameters for start, stop, and terminate methods in BaseBox class ([4480c48](https://github.com/babelcloud/gbox-sdk-py/commit/4480c4858c1ef23eb72efc60f770fca3da0e2082))
* **client:** add follow_redirects request option ([86aa529](https://github.com/babelcloud/gbox-sdk-py/commit/86aa529c6e708fdd8a35f9c23e123788d2f4286f))
* **client:** add support for aiohttp ([0a37597](https://github.com/babelcloud/gbox-sdk-py/commit/0a37597d3fded81a7cfa68c11282dadc913c1714))


### Bug Fixes

* android action error ([dc313a9](https://github.com/babelcloud/gbox-sdk-py/commit/dc313a9003a8a6fcac91800e57a5ccd89a2c8cb7))
* change camelCase to snake_case ([af1efbf](https://github.com/babelcloud/gbox-sdk-py/commit/af1efbf516509aec35b4e73fe8cfe2b2b6f16bfb))
* ci error ([c63c770](https://github.com/babelcloud/gbox-sdk-py/commit/c63c770952222f958d4e5d0996bf914edf4503c2))
* **ci:** correct conditional ([477586c](https://github.com/babelcloud/gbox-sdk-py/commit/477586cafcab0dc81fd8fb3619beac0708e1ceb1))
* **ci:** release-doctor — report correct token name ([268f887](https://github.com/babelcloud/gbox-sdk-py/commit/268f887ef08e1451a6cc8385581d4079d7528050))
* **client:** correctly parse binary response | stream ([d1f8ffd](https://github.com/babelcloud/gbox-sdk-py/commit/d1f8ffd38e37ab8a990060d2a68057620eac6f04))
* docs ci ([f04e244](https://github.com/babelcloud/gbox-sdk-py/commit/f04e2441e448c750758a27ddfb988343373d92cf))
* export GboxSDK ([e24bd33](https://github.com/babelcloud/gbox-sdk-py/commit/e24bd3353cf5cf5332692560abb8b5652cbe5037))
* fs remove ([24e9ef6](https://github.com/babelcloud/gbox-sdk-py/commit/24e9ef684f5dee9080b92a4496c51cb61f187330))
* fs write ([eab3566](https://github.com/babelcloud/gbox-sdk-py/commit/eab35664be88f7fac40813fcef4fe0c71598bf85))
* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([b3d0d94](https://github.com/babelcloud/gbox-sdk-py/commit/b3d0d946c992a233ee49f235c8b5a9f567bcd58a))


### Chores

* **ci:** change upload type ([b6dc53c](https://github.com/babelcloud/gbox-sdk-py/commit/b6dc53ca9ea170752fca1c59edef45c222f4b880))
* **ci:** enable for pull requests ([6ae6987](https://github.com/babelcloud/gbox-sdk-py/commit/6ae6987d2acefdadf1730fd50f07fdf389fdfcec))
* **ci:** only run for pushes and fork pull requests ([0af01c9](https://github.com/babelcloud/gbox-sdk-py/commit/0af01c96dc30750c42956cc719831ed94441381a))
* configure new SDK language ([ebdecca](https://github.com/babelcloud/gbox-sdk-py/commit/ebdecca1b6026f759ac18850ce89c7f5d2a3f64a))
* **docs:** remove reference to rye shell ([29186ff](https://github.com/babelcloud/gbox-sdk-py/commit/29186fffe8e053dc8be2862030d798ea22438eb4))
* **docs:** remove unnecessary param examples ([1dec570](https://github.com/babelcloud/gbox-sdk-py/commit/1dec570e6e156790e684cbcdc4df81b06a0605cd))
* **internal:** bump pinned h11 dep ([0ed8afa](https://github.com/babelcloud/gbox-sdk-py/commit/0ed8afabd61692c4298e79f4008eab45d161097f))
* **internal:** codegen related update ([e41dafb](https://github.com/babelcloud/gbox-sdk-py/commit/e41dafb5a91a92dd2928329a8dc8856e993df1e4))
* **internal:** codegen related update ([e456265](https://github.com/babelcloud/gbox-sdk-py/commit/e45626561d64a49165d9c916f84ce1e9b478b1b1))
* **internal:** codegen related update ([b109699](https://github.com/babelcloud/gbox-sdk-py/commit/b1096998c433bccb68f6f5b7db7a9ab5de355c4a))
* **internal:** codegen related update ([188ca86](https://github.com/babelcloud/gbox-sdk-py/commit/188ca86542c348ae33ea47fd341b4704d5ecc5f5))
* **internal:** codegen related update ([32504d2](https://github.com/babelcloud/gbox-sdk-py/commit/32504d237ec70e40a25f235488d41f9280354239))
* **internal:** update conftest.py ([f9e6b54](https://github.com/babelcloud/gbox-sdk-py/commit/f9e6b541e32ba6f22a007314ceb109707e2b3946))
* **package:** mark python 3.13 as supported ([79e0f21](https://github.com/babelcloud/gbox-sdk-py/commit/79e0f210d8921ee97f4de5df381ba4872a71cdd8))
* **readme:** update badges ([1193cf7](https://github.com/babelcloud/gbox-sdk-py/commit/1193cf7faa1322dfc40ceecd038d33422e17b986))
* sync config ([33ba57d](https://github.com/babelcloud/gbox-sdk-py/commit/33ba57d09b33fba968bcf1db92f2eb4792aef8e9))
* sync repo ([8af8cc9](https://github.com/babelcloud/gbox-sdk-py/commit/8af8cc90cb15e76c69bab846c6b42b0e53c9a3f7))
* **tests:** add tests for httpx client instantiation & proxies ([657c898](https://github.com/babelcloud/gbox-sdk-py/commit/657c898c2b5562ec0a5a2e1683953ef6042e5845))
* **tests:** run tests in parallel ([6fb47d9](https://github.com/babelcloud/gbox-sdk-py/commit/6fb47d9b3026fcd22aa85658f560c41f0606edeb))
* **tests:** skip some failing tests on the latest python versions ([406d869](https://github.com/babelcloud/gbox-sdk-py/commit/406d86938ace6237b8b3184d055281a287de4d2a))
* update SDK settings ([2878195](https://github.com/babelcloud/gbox-sdk-py/commit/28781951f41aa7685e2ace74c8d2de4f8229ead9))
* update SDK settings ([d43dfa9](https://github.com/babelcloud/gbox-sdk-py/commit/d43dfa932601b4ce7a92de8efc9e99a75ddfc248))
* update SDK settings ([11153e3](https://github.com/babelcloud/gbox-sdk-py/commit/11153e337cdfbeb0e0d87c7820792def3e825148))
* update SDK settings ([ef449ed](https://github.com/babelcloud/gbox-sdk-py/commit/ef449ed6db430163109f97be235486d394095f60))
* update SDK settings ([b77e532](https://github.com/babelcloud/gbox-sdk-py/commit/b77e5324a253b54bed8a2dcd640f12260f54dbb2))
* update SDK settings ([5abe7e2](https://github.com/babelcloud/gbox-sdk-py/commit/5abe7e216d3a0f57f9a81a8ac1f9e7a3987b4a97))
* update SDK settings ([655240f](https://github.com/babelcloud/gbox-sdk-py/commit/655240fdf09565118c2bae6ad3009708871f2380))
* update SDK settings ([fe88869](https://github.com/babelcloud/gbox-sdk-py/commit/fe8886987378d53a5eba80f9d6787fcb59c78653))
* update SDK settings ([dfa0134](https://github.com/babelcloud/gbox-sdk-py/commit/dfa01349fdbcd141dff4010e919a2f4ee0c83151))
* update SDK settings ([abbbac6](https://github.com/babelcloud/gbox-sdk-py/commit/abbbac6a302de1fd9a9a349be8f2603b880574dc))
* update SDK settings ([bc404bd](https://github.com/babelcloud/gbox-sdk-py/commit/bc404bdc2872cb253403aa9e397c9b49d41a0d28))
* update SDK settings ([451d39f](https://github.com/babelcloud/gbox-sdk-py/commit/451d39f78a116eb9df2bf3574afa25d0d43d3624))


### Documentation

* add docs ([19f0c7f](https://github.com/babelcloud/gbox-sdk-py/commit/19f0c7f030aae0d7b7cbb33d653b0dbf9a0bd995))
* **client:** fix httpx.Timeout documentation reference ([5dc09c6](https://github.com/babelcloud/gbox-sdk-py/commit/5dc09c6358512e9ba5b31c36bcff876f83323e76))
* fix build ([2477508](https://github.com/babelcloud/gbox-sdk-py/commit/247750848c2626544fd9831f0aa39333f5076309))


### Refactors

* **box:** streamline action methods and enhance type hints for better clarity and usability ([0a06af0](https://github.com/babelcloud/gbox-sdk-py/commit/0a06af000617747c18c274ce666e53ffffcf144b))
* custom code for android ([0557594](https://github.com/babelcloud/gbox-sdk-py/commit/0557594a5bfc84271bf75f0c1384b7473c976649))

## 0.1.0-alpha.22 (2025-07-09)

Full Changelog: [v0.1.0-alpha.21...v0.1.0-alpha.22](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.21...v0.1.0-alpha.22)

### Refactors

* **box:** streamline action methods and enhance type hints for better clarity and usability ([0a06af0](https://github.com/babelcloud/gbox-sdk-py/commit/0a06af000617747c18c274ce666e53ffffcf144b))

## 0.1.0-alpha.21 (2025-07-09)

Full Changelog: [v0.1.0-alpha.20...v0.1.0-alpha.21](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.20...v0.1.0-alpha.21)

### Bug Fixes

* change camelCase to snake_case ([af1efbf](https://github.com/babelcloud/gbox-sdk-py/commit/af1efbf516509aec35b4e73fe8cfe2b2b6f16bfb))

## 0.1.0-alpha.20 (2025-07-09)

Full Changelog: [v0.1.0-alpha.19...v0.1.0-alpha.20](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.19...v0.1.0-alpha.20)

### Features

* **android, fs:** enhance APK installation handling to support multiple input formats including local paths, file URLs, and HTTP URLs ([cc0637b](https://github.com/babelcloud/gbox-sdk-py/commit/cc0637becea76d6772b8b9bb98d09881aba35b8e))


### Bug Fixes

* fs remove ([24e9ef6](https://github.com/babelcloud/gbox-sdk-py/commit/24e9ef684f5dee9080b92a4496c51cb61f187330))

## 0.1.0-alpha.19 (2025-07-09)

Full Changelog: [v0.1.0-alpha.18...v0.1.0-alpha.19](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.18...v0.1.0-alpha.19)

### Features

* **box:** allow optional parameters for start, stop, and terminate methods in BaseBox class ([4480c48](https://github.com/babelcloud/gbox-sdk-py/commit/4480c4858c1ef23eb72efc60f770fca3da0e2082))


### Chores

* **internal:** bump pinned h11 dep ([0ed8afa](https://github.com/babelcloud/gbox-sdk-py/commit/0ed8afabd61692c4298e79f4008eab45d161097f))
* **package:** mark python 3.13 as supported ([79e0f21](https://github.com/babelcloud/gbox-sdk-py/commit/79e0f210d8921ee97f4de5df381ba4872a71cdd8))

## 0.1.0-alpha.18 (2025-07-08)

Full Changelog: [v0.1.0-alpha.17...v0.1.0-alpha.18](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.17...v0.1.0-alpha.18)

### Features

* **action:** enhance screenshot method to support optional parameters and file saving ([24b5108](https://github.com/babelcloud/gbox-sdk-py/commit/24b51082f8c77035a26f532c7b60917aeac173f9))
* **api:** api update ([68a9fed](https://github.com/babelcloud/gbox-sdk-py/commit/68a9fede6b7d427cc5276df731c1aa67896d55d6))
* **api:** enhance box creation and management with unified parameters for Android and Linux boxes ([12227dc](https://github.com/babelcloud/gbox-sdk-py/commit/12227dcce5a9339e8ff69b61ea6748c73f5f1ff8))


### Bug Fixes

* fs write ([eab3566](https://github.com/babelcloud/gbox-sdk-py/commit/eab35664be88f7fac40813fcef4fe0c71598bf85))

## 0.1.0-alpha.17 (2025-07-08)

Full Changelog: [v0.1.0-alpha.16...v0.1.0-alpha.17](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.16...v0.1.0-alpha.17)

### Features

* **action:** add AI action support and extend ActionAIParams ([c58eb20](https://github.com/babelcloud/gbox-sdk-py/commit/c58eb20c4ef2c1248a30cde0983426faffccf7f6))
* **api:** api update ([b0ca803](https://github.com/babelcloud/gbox-sdk-py/commit/b0ca803ba3503f821847ac62e46b51d7a970fb37))
* **api:** api update ([9b2b3dd](https://github.com/babelcloud/gbox-sdk-py/commit/9b2b3dd3e05f8df314126b06e32cd1db4a562f0e))
* **api:** api update ([0c746f8](https://github.com/babelcloud/gbox-sdk-py/commit/0c746f837658b0250cccb92e9296bb09b3f2c0ed))
* **api:** api update ([2a7a023](https://github.com/babelcloud/gbox-sdk-py/commit/2a7a023a2569903a1510ca80da4da281f46f6c5a))
* **api:** api update ([62c5826](https://github.com/babelcloud/gbox-sdk-py/commit/62c5826c5521d045211924e405042588f1876823))
* **api:** api update ([9d8a593](https://github.com/babelcloud/gbox-sdk-py/commit/9d8a5937b9013cceb8cd2daa30f411f6ad20d034))


### Chores

* **ci:** change upload type ([b6dc53c](https://github.com/babelcloud/gbox-sdk-py/commit/b6dc53ca9ea170752fca1c59edef45c222f4b880))

## 0.1.0-alpha.16 (2025-06-30)

Full Changelog: [v0.1.0-alpha.15...v0.1.0-alpha.16](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.15...v0.1.0-alpha.16)

### Features

* **api:** api update ([06cac89](https://github.com/babelcloud/gbox-sdk-py/commit/06cac894f3ffdb9188722aa3ef581992791cf3bc))
* **api:** api update ([21af4de](https://github.com/babelcloud/gbox-sdk-py/commit/21af4de46f968b56449534641ca3316a7439ca0f))
* **api:** api update ([6752ddd](https://github.com/babelcloud/gbox-sdk-py/commit/6752ddd330385562c5d1ed55298f65366aa79ea6))
* **api:** api update ([71f3cf6](https://github.com/babelcloud/gbox-sdk-py/commit/71f3cf6138c16fbf099acbc0a152523297c67f9a))


### Bug Fixes

* android action error ([dc313a9](https://github.com/babelcloud/gbox-sdk-py/commit/dc313a9003a8a6fcac91800e57a5ccd89a2c8cb7))
* **ci:** correct conditional ([477586c](https://github.com/babelcloud/gbox-sdk-py/commit/477586cafcab0dc81fd8fb3619beac0708e1ceb1))

## 0.1.0-alpha.15 (2025-06-28)

Full Changelog: [v0.1.0-alpha.14...v0.1.0-alpha.15](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.14...v0.1.0-alpha.15)

### Chores

* **ci:** only run for pushes and fork pull requests ([0af01c9](https://github.com/babelcloud/gbox-sdk-py/commit/0af01c96dc30750c42956cc719831ed94441381a))

## 0.1.0-alpha.14 (2025-06-27)

Full Changelog: [v0.1.0-alpha.13...v0.1.0-alpha.14](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.13...v0.1.0-alpha.14)

## 0.1.0-alpha.13 (2025-06-27)

Full Changelog: [v0.1.0-alpha.12...v0.1.0-alpha.13](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.12...v0.1.0-alpha.13)

### Documentation

* fix build ([2477508](https://github.com/babelcloud/gbox-sdk-py/commit/247750848c2626544fd9831f0aa39333f5076309))

## 0.1.0-alpha.12 (2025-06-27)

Full Changelog: [v0.1.0-alpha.11...v0.1.0-alpha.12](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.11...v0.1.0-alpha.12)

## 0.1.0-alpha.11 (2025-06-27)

Full Changelog: [v0.1.0-alpha.10...v0.1.0-alpha.11](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.10...v0.1.0-alpha.11)

### Bug Fixes

* docs ci ([f04e244](https://github.com/babelcloud/gbox-sdk-py/commit/f04e2441e448c750758a27ddfb988343373d92cf))

## 0.1.0-alpha.10 (2025-06-27)

Full Changelog: [v0.1.0-alpha.9...v0.1.0-alpha.10](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.9...v0.1.0-alpha.10)

### Bug Fixes

* ci error ([c63c770](https://github.com/babelcloud/gbox-sdk-py/commit/c63c770952222f958d4e5d0996bf914edf4503c2))

## 0.1.0-alpha.9 (2025-06-27)

Full Changelog: [v0.1.0-alpha.8...v0.1.0-alpha.9](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.8...v0.1.0-alpha.9)

## 0.1.0-alpha.8 (2025-06-27)

Full Changelog: [v0.1.0-alpha.7...v0.1.0-alpha.8](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.7...v0.1.0-alpha.8)

## 0.1.0-alpha.7 (2025-06-27)

Full Changelog: [v0.1.0-alpha.6...v0.1.0-alpha.7](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.6...v0.1.0-alpha.7)

## 0.1.0-alpha.6 (2025-06-27)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Documentation

* add docs ([19f0c7f](https://github.com/babelcloud/gbox-sdk-py/commit/19f0c7f030aae0d7b7cbb33d653b0dbf9a0bd995))

## 0.1.0-alpha.5 (2025-06-27)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** api update ([a1c2ae6](https://github.com/babelcloud/gbox-sdk-py/commit/a1c2ae6faa6839414c7dcac8089c9aca40312fd5))
* **api:** api update ([89d5f2d](https://github.com/babelcloud/gbox-sdk-py/commit/89d5f2d2482d987f00b8938f3d6ce7e3da433a42))
* **api:** api update ([bf1941e](https://github.com/babelcloud/gbox-sdk-py/commit/bf1941e1b536b3238b140bea1d2b27526a61980d))
* **api:** api update ([385e786](https://github.com/babelcloud/gbox-sdk-py/commit/385e7860f40a3c8ac69dd8ababd0081fcaeffd67))
* **api:** api update ([1ce1459](https://github.com/babelcloud/gbox-sdk-py/commit/1ce1459fdb30f062267b3cd03798f1aa53d4c8d1))
* **api:** api update ([8ef3437](https://github.com/babelcloud/gbox-sdk-py/commit/8ef34373e38cbbf32ad6d00a8af6ed61dc7747d1))


### Bug Fixes

* **ci:** release-doctor — report correct token name ([268f887](https://github.com/babelcloud/gbox-sdk-py/commit/268f887ef08e1451a6cc8385581d4079d7528050))

## 0.1.0-alpha.4 (2025-06-26)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Bug Fixes

* export GboxSDK ([e24bd33](https://github.com/babelcloud/gbox-sdk-py/commit/e24bd3353cf5cf5332692560abb8b5652cbe5037))

## 0.1.0-alpha.3 (2025-06-26)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Refactors

* custom code for android ([0557594](https://github.com/babelcloud/gbox-sdk-py/commit/0557594a5bfc84271bf75f0c1384b7473c976649))

## 0.1.0-alpha.2 (2025-06-25)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** api update ([1a97852](https://github.com/babelcloud/gbox-sdk-py/commit/1a9785208550d2233505c115ba245a972762e9c1))
* **api:** api update ([df5dfee](https://github.com/babelcloud/gbox-sdk-py/commit/df5dfee51f249af27ea1f2cc9a0b02a80ba2c199))
* **api:** api update ([3da7479](https://github.com/babelcloud/gbox-sdk-py/commit/3da7479394855329abb7c747f378ed0347bdb291))
* **api:** api update ([784ca67](https://github.com/babelcloud/gbox-sdk-py/commit/784ca673d73d1e651a021787b4f5e0f6eb0da939))
* **api:** api update ([f371a5d](https://github.com/babelcloud/gbox-sdk-py/commit/f371a5d0fe10450dc19c5fd59d34ca7ecf6e6311))
* **api:** api update ([9105104](https://github.com/babelcloud/gbox-sdk-py/commit/9105104f2b5d1436b669702c9bb219d9a906c996))
* **api:** api update ([8133a2e](https://github.com/babelcloud/gbox-sdk-py/commit/8133a2eb0e80f03d24a5f8c473dac44cde0b952e))
* **api:** api update ([a3ee1c8](https://github.com/babelcloud/gbox-sdk-py/commit/a3ee1c81a53defc05d10c805333158076e1dee9e))
* **api:** api update ([90f9822](https://github.com/babelcloud/gbox-sdk-py/commit/90f9822d821b244786cd6ce0a2f3a0829b61e9e9))
* **api:** api update ([002833a](https://github.com/babelcloud/gbox-sdk-py/commit/002833ad9c955c670cfc1d3ec3164f8cf15a7625))
* **api:** api update ([bbe9346](https://github.com/babelcloud/gbox-sdk-py/commit/bbe9346f8f29518230ee5e68d6c1d9ac1280000a))
* **api:** api update ([62a2c4b](https://github.com/babelcloud/gbox-sdk-py/commit/62a2c4b1ab5a2990a0982620e53c27967a8a0bbf))
* **api:** api update ([5755604](https://github.com/babelcloud/gbox-sdk-py/commit/575560487caff6e1c0b323f71b1aa4d9decf2ca8))
* **api:** api update ([e151cf3](https://github.com/babelcloud/gbox-sdk-py/commit/e151cf3085785bfb9adde4f1717658d2ab9df725))
* **api:** api update ([12d4278](https://github.com/babelcloud/gbox-sdk-py/commit/12d4278f0fe3a7c669443e74a5e6c1462355db8a))
* **api:** api update ([9ad1d28](https://github.com/babelcloud/gbox-sdk-py/commit/9ad1d283116f9d15d32a0567b499380a1d49a432))
* **api:** api update ([1829e97](https://github.com/babelcloud/gbox-sdk-py/commit/1829e97c1644c31b3a1b658b67a9b7a556141253))
* **api:** api update ([af01124](https://github.com/babelcloud/gbox-sdk-py/commit/af01124f751920d072c485ba87bbb4234fd5203f))
* **api:** api update ([1e313ed](https://github.com/babelcloud/gbox-sdk-py/commit/1e313ed95b981c6751066167c5283780058fbb42))
* **api:** api update ([0361074](https://github.com/babelcloud/gbox-sdk-py/commit/0361074903fab99a6f3d2eb129d0b7a193d2cfbd))
* **api:** api update ([89eb38e](https://github.com/babelcloud/gbox-sdk-py/commit/89eb38e1de1df468c281efe0b8ed0c207587cc8a))
* **api:** api update ([3a428f4](https://github.com/babelcloud/gbox-sdk-py/commit/3a428f43b0af327d78160c20a67f4e6f6fe63608))
* **api:** api update ([55ac95e](https://github.com/babelcloud/gbox-sdk-py/commit/55ac95ee15183da8f6550998ab71e45decc8bb74))
* **api:** api update ([bab02cb](https://github.com/babelcloud/gbox-sdk-py/commit/bab02cba5c4bc934278b8103e9629bda225c409f))
* **api:** api update ([bae1c5c](https://github.com/babelcloud/gbox-sdk-py/commit/bae1c5c5338e272ac51728ae0d2eb82f668f273f))
* **api:** api update ([32245ed](https://github.com/babelcloud/gbox-sdk-py/commit/32245edcc14eb4e4552942b9e4781833610a54a6))
* **api:** api update ([0cee4a7](https://github.com/babelcloud/gbox-sdk-py/commit/0cee4a7bf0b4801e99792375e9075fbb61755825))
* **api:** api update ([39ab273](https://github.com/babelcloud/gbox-sdk-py/commit/39ab2736256da51ceef7fd72bf87736ebcd856e1))
* **api:** api update ([9b8d6f8](https://github.com/babelcloud/gbox-sdk-py/commit/9b8d6f8958e7f9e3122996298496c947250f3e9e))
* **api:** api update ([462b313](https://github.com/babelcloud/gbox-sdk-py/commit/462b3138f408b784c3ea1fe931db8ed2ef123a9a))
* **api:** api update ([874fb44](https://github.com/babelcloud/gbox-sdk-py/commit/874fb446e1c59d6b17a4c49961c9435a933e61b6))
* **api:** api update ([1ce6554](https://github.com/babelcloud/gbox-sdk-py/commit/1ce6554bba010bc002b490f8baa485b7641b69e5))
* **api:** api update ([55a6d7d](https://github.com/babelcloud/gbox-sdk-py/commit/55a6d7d0e9a46ff993f4f5732be41280656000aa))
* **api:** api update ([75bfcde](https://github.com/babelcloud/gbox-sdk-py/commit/75bfcde9fea96fa035f47367054946a68ea48d34))
* **api:** api update ([1c41908](https://github.com/babelcloud/gbox-sdk-py/commit/1c419083685302a991156bc50148862299383ce0))
* **api:** api update ([33d8679](https://github.com/babelcloud/gbox-sdk-py/commit/33d86797f41da3fc8dd5e255697bd3545cafcad5))
* **api:** api update ([f568c85](https://github.com/babelcloud/gbox-sdk-py/commit/f568c857299cb093c000c2a862192d960ebc1bbd))
* **api:** api update ([9b6f9de](https://github.com/babelcloud/gbox-sdk-py/commit/9b6f9de4aec8c06f7656e56f680079e5959e40f8))
* **api:** api update ([f6fb04b](https://github.com/babelcloud/gbox-sdk-py/commit/f6fb04b5e56de779bb2cc829bbf56966b8b1749b))
* **api:** api update ([975884c](https://github.com/babelcloud/gbox-sdk-py/commit/975884ce6f565dbcd1829028ae7ad5d20dc5bcec))
* **api:** api update ([e3badb0](https://github.com/babelcloud/gbox-sdk-py/commit/e3badb0a6e72f48f3b75897db9bd24f453fcb1bd))
* **api:** api update ([568484b](https://github.com/babelcloud/gbox-sdk-py/commit/568484b9961d267466c382ec36c30b9fac558425))
* **api:** api update ([3277243](https://github.com/babelcloud/gbox-sdk-py/commit/32772434884f859363eee941fbf6d8238cbfb36d))
* **api:** api update ([8cc0a38](https://github.com/babelcloud/gbox-sdk-py/commit/8cc0a38268abaa14acf21d00f9681e35e7869a27))
* **api:** api update ([9029aab](https://github.com/babelcloud/gbox-sdk-py/commit/9029aabb651500a65bbd81d9dc6726627b859180))
* **api:** api update ([8c641f4](https://github.com/babelcloud/gbox-sdk-py/commit/8c641f470a37badd59a53778cb328a440fad50bc))
* **api:** api update ([a820b3f](https://github.com/babelcloud/gbox-sdk-py/commit/a820b3fa2609846515b43a2e6875405a784e2ed2))
* **api:** api update ([4280a67](https://github.com/babelcloud/gbox-sdk-py/commit/4280a67ad066fa691fdf06689adc42cf818e588d))
* **api:** api update ([5a3e3ce](https://github.com/babelcloud/gbox-sdk-py/commit/5a3e3ce9d0f8e058bf168e36a35e673c7fbcc2b3))
* **api:** api update ([f91642f](https://github.com/babelcloud/gbox-sdk-py/commit/f91642f964a2e51647cb054977bedc665d6923e9))
* **api:** api update ([f4efa25](https://github.com/babelcloud/gbox-sdk-py/commit/f4efa25622088a1cfe2fa2187c1d8090368fc3e7))
* **api:** api update ([481f354](https://github.com/babelcloud/gbox-sdk-py/commit/481f35440439916da2836659fdf125086ce12a20))
* **api:** api update ([81beaf6](https://github.com/babelcloud/gbox-sdk-py/commit/81beaf6636b3c250255de43068835ca1a7b7dd95))
* **api:** api update ([4eba864](https://github.com/babelcloud/gbox-sdk-py/commit/4eba8647159e65cd74dfb385f2d958182331eb4a))
* **api:** api update ([cdb0e97](https://github.com/babelcloud/gbox-sdk-py/commit/cdb0e97c8cf191b36a9bf76724db4be676832e64))
* **api:** api update ([7c07d26](https://github.com/babelcloud/gbox-sdk-py/commit/7c07d269a33cb90759d90344e46490408dd822d3))
* **api:** api update ([5cf58a9](https://github.com/babelcloud/gbox-sdk-py/commit/5cf58a901471fce9dca71356b6e23aac91c02bdd))
* **api:** api update ([abe1ca5](https://github.com/babelcloud/gbox-sdk-py/commit/abe1ca5e7e29ba9cb802c52ddf961a71779216fd))
* **api:** api update ([5cce3d5](https://github.com/babelcloud/gbox-sdk-py/commit/5cce3d5b4f7bac209a59c466f196ab46424ed77b))
* **api:** api update ([1dbccff](https://github.com/babelcloud/gbox-sdk-py/commit/1dbccff9140302900f1de07e168421b889b4ed1f))
* **api:** api update ([78e2d17](https://github.com/babelcloud/gbox-sdk-py/commit/78e2d17e5d1620c6542bf934dcfd8305bc8456eb))
* **api:** api update ([7b3e36f](https://github.com/babelcloud/gbox-sdk-py/commit/7b3e36f84004f5a7ea7513dec28730cef8f9728e))
* **api:** api update ([17dbf3a](https://github.com/babelcloud/gbox-sdk-py/commit/17dbf3aa1d6aed4cc9b8ca574ec4f9018b96648e))
* **api:** api update ([56c90f3](https://github.com/babelcloud/gbox-sdk-py/commit/56c90f37772161878298a96e57163afd5f7165a7))
* **api:** api update ([26b0d82](https://github.com/babelcloud/gbox-sdk-py/commit/26b0d8254192669ff10804e51b9935c5af8ddf9f))
* **api:** api update ([f149278](https://github.com/babelcloud/gbox-sdk-py/commit/f1492784c839c750788bdda7a8225bb7f9c72641))
* **api:** api update ([a919aaf](https://github.com/babelcloud/gbox-sdk-py/commit/a919aaf379961c1b7bf3a9d4b16ea716b4857d36))
* **api:** api update ([33de52f](https://github.com/babelcloud/gbox-sdk-py/commit/33de52f43e0f71747ecea3171e8445127904c5a6))
* **api:** api update ([5fe515c](https://github.com/babelcloud/gbox-sdk-py/commit/5fe515c987e40ba6eeada913a9cecff5159cfb33))
* **api:** api update ([0991e0e](https://github.com/babelcloud/gbox-sdk-py/commit/0991e0e88081a6fcbb4cec70a6d92b481f5f9019))
* **api:** api update ([5c1b649](https://github.com/babelcloud/gbox-sdk-py/commit/5c1b649de6650f639dc6723985c293474f477871))
* **api:** api update ([bf932a1](https://github.com/babelcloud/gbox-sdk-py/commit/bf932a145e86dd9d650ca8b221783b97779eeb16))
* **api:** api update ([21423ce](https://github.com/babelcloud/gbox-sdk-py/commit/21423ce58b68b4132947c561f0b6a72facbb1e4f))
* **api:** api update ([516f187](https://github.com/babelcloud/gbox-sdk-py/commit/516f18737316cde5715adac83bebc2c136116f14))
* **api:** api update ([e634222](https://github.com/babelcloud/gbox-sdk-py/commit/e63422205b3a2b7d53c73775b60a8784a33fdb3d))
* **api:** api update ([8b53b53](https://github.com/babelcloud/gbox-sdk-py/commit/8b53b53cf89837d0b49761d09b84fd41dcb7f028))
* **api:** api update ([623b01c](https://github.com/babelcloud/gbox-sdk-py/commit/623b01c6fb6396ec952d7271b2039ec592b62631))
* **api:** api update ([b866218](https://github.com/babelcloud/gbox-sdk-py/commit/b8662185a6544fa80b57496a8a38540ca178960e))
* **api:** api update ([e9775fd](https://github.com/babelcloud/gbox-sdk-py/commit/e9775fd99203595149e9621d44a76e49ff4a2f7e))
* **api:** api update ([3df4a6f](https://github.com/babelcloud/gbox-sdk-py/commit/3df4a6f58c2908e0204835bc13ef48cb31312091))
* **api:** api update ([03ecf6c](https://github.com/babelcloud/gbox-sdk-py/commit/03ecf6c7204bab91c7994d613584206960eaf552))
* **api:** api update ([288ce1b](https://github.com/babelcloud/gbox-sdk-py/commit/288ce1be34525d6be88e5dd0367e21c1f8b2a84b))
* **api:** api update ([245aad5](https://github.com/babelcloud/gbox-sdk-py/commit/245aad5e47e70291c2060e5b7fff6f1ce211ce53))
* **api:** api update ([550cdde](https://github.com/babelcloud/gbox-sdk-py/commit/550cdde72c20c3768ea333b4e4aef27dd9532ec4))
* **api:** api update ([a88dcb9](https://github.com/babelcloud/gbox-sdk-py/commit/a88dcb9bddd7466f1fd45f689203bc6446982fed))
* **client:** add support for aiohttp ([0a37597](https://github.com/babelcloud/gbox-sdk-py/commit/0a37597d3fded81a7cfa68c11282dadc913c1714))


### Bug Fixes

* **client:** correctly parse binary response | stream ([d1f8ffd](https://github.com/babelcloud/gbox-sdk-py/commit/d1f8ffd38e37ab8a990060d2a68057620eac6f04))
* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([b3d0d94](https://github.com/babelcloud/gbox-sdk-py/commit/b3d0d946c992a233ee49f235c8b5a9f567bcd58a))


### Chores

* **ci:** enable for pull requests ([6ae6987](https://github.com/babelcloud/gbox-sdk-py/commit/6ae6987d2acefdadf1730fd50f07fdf389fdfcec))
* **internal:** codegen related update ([e41dafb](https://github.com/babelcloud/gbox-sdk-py/commit/e41dafb5a91a92dd2928329a8dc8856e993df1e4))
* **internal:** codegen related update ([e456265](https://github.com/babelcloud/gbox-sdk-py/commit/e45626561d64a49165d9c916f84ce1e9b478b1b1))
* **internal:** codegen related update ([b109699](https://github.com/babelcloud/gbox-sdk-py/commit/b1096998c433bccb68f6f5b7db7a9ab5de355c4a))
* **internal:** codegen related update ([188ca86](https://github.com/babelcloud/gbox-sdk-py/commit/188ca86542c348ae33ea47fd341b4704d5ecc5f5))
* **internal:** codegen related update ([32504d2](https://github.com/babelcloud/gbox-sdk-py/commit/32504d237ec70e40a25f235488d41f9280354239))
* **internal:** update conftest.py ([f9e6b54](https://github.com/babelcloud/gbox-sdk-py/commit/f9e6b541e32ba6f22a007314ceb109707e2b3946))
* **readme:** update badges ([1193cf7](https://github.com/babelcloud/gbox-sdk-py/commit/1193cf7faa1322dfc40ceecd038d33422e17b986))
* sync repo ([8af8cc9](https://github.com/babelcloud/gbox-sdk-py/commit/8af8cc90cb15e76c69bab846c6b42b0e53c9a3f7))
* **tests:** add tests for httpx client instantiation & proxies ([657c898](https://github.com/babelcloud/gbox-sdk-py/commit/657c898c2b5562ec0a5a2e1683953ef6042e5845))
* **tests:** run tests in parallel ([6fb47d9](https://github.com/babelcloud/gbox-sdk-py/commit/6fb47d9b3026fcd22aa85658f560c41f0606edeb))
* **tests:** skip some failing tests on the latest python versions ([406d869](https://github.com/babelcloud/gbox-sdk-py/commit/406d86938ace6237b8b3184d055281a287de4d2a))
* update SDK settings ([2878195](https://github.com/babelcloud/gbox-sdk-py/commit/28781951f41aa7685e2ace74c8d2de4f8229ead9))
* update SDK settings ([d43dfa9](https://github.com/babelcloud/gbox-sdk-py/commit/d43dfa932601b4ce7a92de8efc9e99a75ddfc248))
* update SDK settings ([11153e3](https://github.com/babelcloud/gbox-sdk-py/commit/11153e337cdfbeb0e0d87c7820792def3e825148))
* update SDK settings ([ef449ed](https://github.com/babelcloud/gbox-sdk-py/commit/ef449ed6db430163109f97be235486d394095f60))
* update SDK settings ([b77e532](https://github.com/babelcloud/gbox-sdk-py/commit/b77e5324a253b54bed8a2dcd640f12260f54dbb2))
* update SDK settings ([5abe7e2](https://github.com/babelcloud/gbox-sdk-py/commit/5abe7e216d3a0f57f9a81a8ac1f9e7a3987b4a97))
* update SDK settings ([655240f](https://github.com/babelcloud/gbox-sdk-py/commit/655240fdf09565118c2bae6ad3009708871f2380))
* update SDK settings ([fe88869](https://github.com/babelcloud/gbox-sdk-py/commit/fe8886987378d53a5eba80f9d6787fcb59c78653))


### Documentation

* **client:** fix httpx.Timeout documentation reference ([5dc09c6](https://github.com/babelcloud/gbox-sdk-py/commit/5dc09c6358512e9ba5b31c36bcff876f83323e76))
